@@ -62,7 +62,7 @@ class EmailParserError(RuntimeError):
 
 
 class DownloadError(RuntimeError):
-    """Rasied when an error occurs when downloading a file"""
+    """Raised when an error occurs when downloading a file"""
 
 
 def decode_base64(data):
@@ -292,6 +292,13 @@ def get_ip_address_country(ip_address, db_path=None):
         "dbip-country.mmdb",
     ]
 
+    if db_path is not None:
+        if os.path.isfile(db_path) is False:
+            db_path = None
+            logger.warning(f"No file exists at {db_path}. Falling back to an "
+                           "included copy of the IPDB IP to Country "
+                           "Lite database.")
+
     if db_path is None:
         for system_path in db_paths:
             if os.path.exists(system_path):
